==> nxnode-3.0.0-83.x86_64.tar.gz: NX/scripts/restricted/nxuserdel.sh <==
#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.r.l.                     #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################

PATH="/usr/sbin:/usr/bin" && export PATH

COMMAND_ECHO="/bin/echo"

if test $# -ne 4 ; then
  $COMMAND_ECHO "NX> 599 Error: Wrong parameters count." && exit 1
fi

if [ "x$1" != "xnx" -a "x$1" != "xroot" ];
then
  $COMMAND_ECHO "NX> 599 Error: nxuserdel.sh: only 'nx' user can remove a system user by this script" 1>&2
  exit 1
fi

COMMAND_USERDEL="/usr/sbin/userdel"

if [ ! -x $COMMAND_USERDEL ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_USERDEL doesn't exist"
  exit 1
elif [ "x$4" = "x1" ];
then
  exec $COMMAND_USERDEL -r $3
else  
  exec $COMMAND_USERDEL $3
fi

==> nxnode-3.1.0-6.x86_64.tar.gz: NX/scripts/restricted/nxuserdel.sh <==
#!/bin/sh
############################################################################
#                                                                          #
#  Copyright (c) 2001, 2007 NoMachine, http://www.nomachine.com.           #
#                                                                          #
#  NXSERVER, NX protocol compression and NX extensions to this software    #
#  are copyright of NoMachine. Redistribution and use of the present       #
#  software is allowed according to terms specified in the file LICENSE    #
#  which comes in the source distribution.                                 #
#                                                                          #
#  Check http://www.nomachine.com/licensing.html for applicability.        #
#                                                                          #
#  NX and NoMachine are trademarks of NoMachine S.r.l.                     #
#                                                                          #
#  All rigths reserved.                                                    #
#                                                                          #
############################################################################

PATH="/usr/sbin:/usr/bin" && export PATH

COMMAND_ECHO="/bin/echo"
COMMAND_NSCD="/usr/sbin/nscd"

if test $# -ne 4 ; then
  $COMMAND_ECHO "NX> 599 Error: Wrong parameters count." && exit 1
fi

if [ "x$1" != "xnx" -a "x$1" != "xroot" ];
then
  $COMMAND_ECHO "NX> 599 Error: nxuserdel.sh: only 'nx' user can remove a system user by this script" 1>&2
  exit 1
fi

COMMAND_USERDEL="/usr/sbin/userdel"

if [ ! -x $COMMAND_USERDEL ];
then
  $COMMAND_ECHO "NX> 599 Error: command $COMMAND_USERDEL doesn't exist"
  exit 1
elif [ "x$4" = "x1" ];
then
  $COMMAND_USERDEL -r $3
else  
  $COMMAND_USERDEL $3
fi

if [ $? != 0 ];
then
  exit $?
fi

if [ -f /etc/nscd.conf ];
then
  $COMMAND_NSCD -i passwd
fi

exit 0
